import React, { FC, useCallback } from 'react';
import { View, StyleSheet, TouchableOpacity, Image, TextStyle, StyleProp } from 'react-native';
import { TYText, IconFont } from 'tuya-panel-kit';
import icons from '@icons';
import { convertX } from '@utils/ration';


interface Props {
  label: string;
  dragEnabled?: boolean;
  icon?: number;
  style?: any;
  titleStyle?: StyleProp<TextStyle>;
  isRemove?: boolean;
  required?: boolean;
  onPress: () => void;
  onDrag?: () => void;
}

const Item: FC<Props> = ({
  label,
  icon,
  dragEnabled,
  isRemove,
  required,
  onPress,
  onDrag,
  style,
  titleStyle,
}) => {
  // const handleClick = useCallback(() => {
  // }, []);
  const handleDrag = useCallback(() => {
    onDrag && onDrag();
  }, [onPress]);
  return (
    <View style={[styles.row, style]}>
      {!required && (
        <TouchableOpacity style={styles.btn} activeOpacity={0.7} onPress={onPress}>
          <IconFont
            d={isRemove ? icons.remove : icons.addfill}
            size={convertX(22)}
            color={isRemove ? '#FF4444' : '#3ACE53'}
          />
        </TouchableOpacity>
      )}

      {icon && <Image style={styles.icon} source={icon} />}
      <View style={styles.rightContent}>
        <TYText style={[styles.title, titleStyle]}>{label}</TYText>
      </View>
      {dragEnabled && (
        <TouchableOpacity style={styles.more} activeOpacity={0.7} onPressIn={handleDrag}>
          <IconFont d={icons.menu} size={convertX(20)} color="#BFBFBF" />
        </TouchableOpacity>
      )}
    </View>
  );
};

export default Item;
const styles = StyleSheet.create({
  btn: {
    width: convertX(22),
    height: convertX(38),
    justifyContent: 'center',
    alignItems: 'center',
  },
  row: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingVertical: convertX(15),
    paddingLeft: convertX(20),
    height: convertX(70),
  },
  icon: {
    borderRadius: convertX(19),
    width: convertX(38),
    height: convertX(38),
    justifyContent: 'center',
    alignItems: 'center',
    marginRight: convertX(2),
    marginLeft: convertX(12),
  },
  rightContent: {
    flex: 1,
    marginLeft: convertX(16),
    justifyContent: 'center',
  },
  title: {
    fontSize: 16,
    marginBottom: 4,
  },
  more: {
    width: convertX(56),
    // height: '100%',
    justifyContent: 'center',
    alignItems: 'flex-end',
    paddingRight: convertX(20),
  },
});
